@@ -241,7 +241,7 @@ class FaustApp:
         self.worker.on_start = self.on_start
         self.worker.on_shutdown = self.on_shutdown
         self.worker.on_setup_root_logger = self.on_setup_root_logger
-        self.logger = logging.getLogger(self.app._conf.id)
+        self.logger = logging.getLogger(self.pipeline_name)
 
     def start(self, agents: List[FaustAgent]):
         try:
@@ -286,14 +286,14 @@ class FaustApp:
 
     async def attach(self, agent: FaustAgent):
         agent.step_config = self.get_step_config(agent.step)
-        agent.agent_id = f"{self.app._conf.id}.{agent.step}"
-        agent.logger = logging.getLogger(f"{self.app._conf.id}] [{agent.step}")
+        agent.agent_id = f"{self.pipeline_name}.{agent.step}"
+        agent.logger = logging.getLogger(f"{self.pipeline_name}] [{agent.step}")
         agent.input_topic = self.app.topic(
             agent.agent_id,
             value_type=agent.input_value_type,
             value_serializer=agent.input_value_serializer,
         )
-        output_topic_name = f"{self.app._conf.id}.{agent.step_config.output}"
+        output_topic_name = f"{self.pipeline_name}.{agent.step_config.output}"
         agent.output_topic = self.app.topic(
             output_topic_name,
             value_serializer=agent.output_value_serializer,
