@@ -181,7 +181,11 @@ def get_http_handlers(
             raw_output = await process_grpc_request(
                 descriptor, service_name, method, input, channel, metadata=metadata
             )
-            output = MessageToDict(raw_output, preserving_proto_field_name=True)
+            output = MessageToDict(
+                raw_output,
+                preserving_proto_field_name=True,
+                including_default_value_fields=True,
+            )
             return JSONResponse(output)
         except AioRpcError as ex:
             detail = ex.details()
